# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .access_group import *
from .access_group_project import *
from .alias import *
from .attack_challenge_mode import *
from .custom_certificate import *
from .custom_environment import *
from .deployment import *
from .dns_record import *
from .edge_config import *
from .edge_config_item import *
from .edge_config_schema import *
from .edge_config_token import *
from .firewall_bypass import *
from .firewall_config import *
from .get_access_group import *
from .get_access_group_project import *
from .get_alias import *
from .get_attack_challenge_mode import *
from .get_custom_environment import *
from .get_deployment import *
from .get_domain_config import *
from .get_dsync_groups import *
from .get_edge_config import *
from .get_edge_config_item import *
from .get_edge_config_schema import *
from .get_edge_config_token import *
from .get_endpoint_verification import *
from .get_file import *
from .get_log_drain import *
from .get_microfrontend_group import *
from .get_microfrontend_group_membership import *
from .get_network import *
from .get_prebuilt_project import *
from .get_project import *
from .get_project_deployment_retention import *
from .get_project_directory import *
from .get_project_members import *
from .get_project_rolling_release import *
from .get_shared_environment_variable import *
from .get_team_config import *
from .get_team_member import *
from .integration_project_access import *
from .log_drain import *
from .microfrontend_group import *
from .microfrontend_group_membership import *
from .network import *
from .project import *
from .project_crons import *
from .project_deployment_retention import *
from .project_domain import *
from .project_environment_variable import *
from .project_environment_variables import *
from .project_members import *
from .project_rolling_release import *
from .provider import *
from .shared_environment_variable import *
from .shared_environment_variable_project_link import *
from .team_config import *
from .team_member import *
from .webhook import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumiverse_vercel.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumiverse_vercel.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "vercel",
  "mod": "index/accessGroup",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/accessGroup:AccessGroup": "AccessGroup"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/accessGroupProject",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/accessGroupProject:AccessGroupProject": "AccessGroupProject"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/alias",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/alias:Alias": "Alias"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/attackChallengeMode",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/attackChallengeMode:AttackChallengeMode": "AttackChallengeMode"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/customCertificate",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/customCertificate:CustomCertificate": "CustomCertificate"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/customEnvironment",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/customEnvironment:CustomEnvironment": "CustomEnvironment"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/deployment",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/deployment:Deployment": "Deployment"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/dnsRecord",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/dnsRecord:DnsRecord": "DnsRecord"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/edgeConfig",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/edgeConfig:EdgeConfig": "EdgeConfig"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/edgeConfigItem",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/edgeConfigItem:EdgeConfigItem": "EdgeConfigItem"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/edgeConfigSchema",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/edgeConfigSchema:EdgeConfigSchema": "EdgeConfigSchema"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/edgeConfigToken",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/edgeConfigToken:EdgeConfigToken": "EdgeConfigToken"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/firewallBypass",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/firewallBypass:FirewallBypass": "FirewallBypass"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/firewallConfig",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/firewallConfig:FirewallConfig": "FirewallConfig"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/integrationProjectAccess",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/integrationProjectAccess:IntegrationProjectAccess": "IntegrationProjectAccess"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/logDrain",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/logDrain:LogDrain": "LogDrain"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/microfrontendGroup",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/microfrontendGroup:MicrofrontendGroup": "MicrofrontendGroup"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/microfrontendGroupMembership",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/microfrontendGroupMembership:MicrofrontendGroupMembership": "MicrofrontendGroupMembership"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/network",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/network:Network": "Network"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/project",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/project:Project": "Project"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/projectCrons",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/projectCrons:ProjectCrons": "ProjectCrons"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/projectDeploymentRetention",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/projectDeploymentRetention:ProjectDeploymentRetention": "ProjectDeploymentRetention"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/projectDomain",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/projectDomain:ProjectDomain": "ProjectDomain"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/projectEnvironmentVariable",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/projectEnvironmentVariable:ProjectEnvironmentVariable": "ProjectEnvironmentVariable"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/projectEnvironmentVariables",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/projectEnvironmentVariables:ProjectEnvironmentVariables": "ProjectEnvironmentVariables"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/projectMembers",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/projectMembers:ProjectMembers": "ProjectMembers"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/projectRollingRelease",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/projectRollingRelease:ProjectRollingRelease": "ProjectRollingRelease"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/sharedEnvironmentVariable",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/sharedEnvironmentVariable:SharedEnvironmentVariable": "SharedEnvironmentVariable"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/sharedEnvironmentVariableProjectLink",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/sharedEnvironmentVariableProjectLink:SharedEnvironmentVariableProjectLink": "SharedEnvironmentVariableProjectLink"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/teamConfig",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/teamConfig:TeamConfig": "TeamConfig"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/teamMember",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/teamMember:TeamMember": "TeamMember"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/webhook",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/webhook:Webhook": "Webhook"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "vercel",
  "token": "pulumi:providers:vercel",
  "fqn": "pulumiverse_vercel",
  "class": "Provider"
 }
]
"""
)
