# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetNetworkResult',
    'AwaitableGetNetworkResult',
    'get_network',
    'get_network_output',
]

@pulumi.output_type
class GetNetworkResult:
    """
    A collection of values returned by getNetwork.
    """
    def __init__(__self__, aws_account_id=None, aws_availability_zone_ids=None, aws_region=None, cidr=None, egress_ip_addresses=None, id=None, name=None, region=None, status=None, team_id=None, vpc_id=None):
        if aws_account_id and not isinstance(aws_account_id, str):
            raise TypeError("Expected argument 'aws_account_id' to be a str")
        pulumi.set(__self__, "aws_account_id", aws_account_id)
        if aws_availability_zone_ids and not isinstance(aws_availability_zone_ids, list):
            raise TypeError("Expected argument 'aws_availability_zone_ids' to be a list")
        pulumi.set(__self__, "aws_availability_zone_ids", aws_availability_zone_ids)
        if aws_region and not isinstance(aws_region, str):
            raise TypeError("Expected argument 'aws_region' to be a str")
        pulumi.set(__self__, "aws_region", aws_region)
        if cidr and not isinstance(cidr, str):
            raise TypeError("Expected argument 'cidr' to be a str")
        pulumi.set(__self__, "cidr", cidr)
        if egress_ip_addresses and not isinstance(egress_ip_addresses, list):
            raise TypeError("Expected argument 'egress_ip_addresses' to be a list")
        pulumi.set(__self__, "egress_ip_addresses", egress_ip_addresses)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if team_id and not isinstance(team_id, str):
            raise TypeError("Expected argument 'team_id' to be a str")
        pulumi.set(__self__, "team_id", team_id)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)

    @_builtins.property
    @pulumi.getter(name="awsAccountId")
    def aws_account_id(self) -> _builtins.str:
        """
        The ID of the AWS Account in which the network exists.
        """
        return pulumi.get(self, "aws_account_id")

    @_builtins.property
    @pulumi.getter(name="awsAvailabilityZoneIds")
    def aws_availability_zone_ids(self) -> Sequence[_builtins.str]:
        """
        The IDs of the AWS Availability Zones in which the network exists, if specified during creation.
        """
        return pulumi.get(self, "aws_availability_zone_ids")

    @_builtins.property
    @pulumi.getter(name="awsRegion")
    def aws_region(self) -> _builtins.str:
        """
        The AWS Region in which the network exists.
        """
        return pulumi.get(self, "aws_region")

    @_builtins.property
    @pulumi.getter
    def cidr(self) -> _builtins.str:
        """
        The CIDR range of the Network.
        """
        return pulumi.get(self, "cidr")

    @_builtins.property
    @pulumi.getter(name="egressIpAddresses")
    def egress_ip_addresses(self) -> Sequence[_builtins.str]:
        """
        The egress IP addresses of the Network.
        """
        return pulumi.get(self, "egress_ip_addresses")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique identifier of the Network.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the network.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        The Vercel region in which the Network exists.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        The status of the Network.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[_builtins.str]:
        """
        The unique identifier of the Team that owns the Network. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @_builtins.property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> _builtins.str:
        """
        The ID of the AWS VPC which hosts the network.
        """
        return pulumi.get(self, "vpc_id")


class AwaitableGetNetworkResult(GetNetworkResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNetworkResult(
            aws_account_id=self.aws_account_id,
            aws_availability_zone_ids=self.aws_availability_zone_ids,
            aws_region=self.aws_region,
            cidr=self.cidr,
            egress_ip_addresses=self.egress_ip_addresses,
            id=self.id,
            name=self.name,
            region=self.region,
            status=self.status,
            team_id=self.team_id,
            vpc_id=self.vpc_id)


def get_network(id: Optional[_builtins.str] = None,
                team_id: Optional[_builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNetworkResult:
    """
    Provides information about a Vercel Network.


    :param _builtins.str id: The unique identifier of the Network.
    :param _builtins.str team_id: The unique identifier of the Team that owns the Network. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vercel:index/getNetwork:getNetwork', __args__, opts=opts, typ=GetNetworkResult).value

    return AwaitableGetNetworkResult(
        aws_account_id=pulumi.get(__ret__, 'aws_account_id'),
        aws_availability_zone_ids=pulumi.get(__ret__, 'aws_availability_zone_ids'),
        aws_region=pulumi.get(__ret__, 'aws_region'),
        cidr=pulumi.get(__ret__, 'cidr'),
        egress_ip_addresses=pulumi.get(__ret__, 'egress_ip_addresses'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        region=pulumi.get(__ret__, 'region'),
        status=pulumi.get(__ret__, 'status'),
        team_id=pulumi.get(__ret__, 'team_id'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'))
def get_network_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                       team_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNetworkResult]:
    """
    Provides information about a Vercel Network.


    :param _builtins.str id: The unique identifier of the Network.
    :param _builtins.str team_id: The unique identifier of the Team that owns the Network. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vercel:index/getNetwork:getNetwork', __args__, opts=opts, typ=GetNetworkResult)
    return __ret__.apply(lambda __response__: GetNetworkResult(
        aws_account_id=pulumi.get(__response__, 'aws_account_id'),
        aws_availability_zone_ids=pulumi.get(__response__, 'aws_availability_zone_ids'),
        aws_region=pulumi.get(__response__, 'aws_region'),
        cidr=pulumi.get(__response__, 'cidr'),
        egress_ip_addresses=pulumi.get(__response__, 'egress_ip_addresses'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        region=pulumi.get(__response__, 'region'),
        status=pulumi.get(__response__, 'status'),
        team_id=pulumi.get(__response__, 'team_id'),
        vpc_id=pulumi.get(__response__, 'vpc_id')))
