# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NetworkArgs', 'Network']

@pulumi.input_type
class NetworkArgs:
    def __init__(__self__, *,
                 cidr: pulumi.Input[_builtins.str],
                 region: pulumi.Input[_builtins.str],
                 aws_availability_zone_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input['NetworkTimeoutsArgs']] = None):
        """
        The set of arguments for constructing a Network resource.
        :param pulumi.Input[_builtins.str] cidr: The CIDR range of the Network.
        :param pulumi.Input[_builtins.str] region: The Vercel region in which the Network exists.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] aws_availability_zone_ids: The IDs of the AWS Availability Zones in which the network exists, if specified during creation.
        :param pulumi.Input[_builtins.str] name: The name of the network.
        :param pulumi.Input[_builtins.str] team_id: The unique identifier of the Team that owns the Network. Required when configuring a team resource if a default team has not been set in the provider.
        """
        pulumi.set(__self__, "cidr", cidr)
        pulumi.set(__self__, "region", region)
        if aws_availability_zone_ids is not None:
            pulumi.set(__self__, "aws_availability_zone_ids", aws_availability_zone_ids)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if timeouts is not None:
            pulumi.set(__self__, "timeouts", timeouts)

    @_builtins.property
    @pulumi.getter
    def cidr(self) -> pulumi.Input[_builtins.str]:
        """
        The CIDR range of the Network.
        """
        return pulumi.get(self, "cidr")

    @cidr.setter
    def cidr(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cidr", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Input[_builtins.str]:
        """
        The Vercel region in which the Network exists.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="awsAvailabilityZoneIds")
    def aws_availability_zone_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The IDs of the AWS Availability Zones in which the network exists, if specified during creation.
        """
        return pulumi.get(self, "aws_availability_zone_ids")

    @aws_availability_zone_ids.setter
    def aws_availability_zone_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "aws_availability_zone_ids", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the network.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier of the Team that owns the Network. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)

    @_builtins.property
    @pulumi.getter
    def timeouts(self) -> Optional[pulumi.Input['NetworkTimeoutsArgs']]:
        return pulumi.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: Optional[pulumi.Input['NetworkTimeoutsArgs']]):
        pulumi.set(self, "timeouts", value)


@pulumi.input_type
class _NetworkState:
    def __init__(__self__, *,
                 aws_account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_availability_zone_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 aws_region: Optional[pulumi.Input[_builtins.str]] = None,
                 cidr: Optional[pulumi.Input[_builtins.str]] = None,
                 egress_ip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input['NetworkTimeoutsArgs']] = None,
                 vpc_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Network resources.
        :param pulumi.Input[_builtins.str] aws_account_id: The ID of the AWS Account in which the network exists.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] aws_availability_zone_ids: The IDs of the AWS Availability Zones in which the network exists, if specified during creation.
        :param pulumi.Input[_builtins.str] aws_region: The AWS Region in which the network exists.
        :param pulumi.Input[_builtins.str] cidr: The CIDR range of the Network.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] egress_ip_addresses: The egress IP addresses of the Network.
        :param pulumi.Input[_builtins.str] name: The name of the network.
        :param pulumi.Input[_builtins.str] region: The Vercel region in which the Network exists.
        :param pulumi.Input[_builtins.str] status: The status of the Network.
        :param pulumi.Input[_builtins.str] team_id: The unique identifier of the Team that owns the Network. Required when configuring a team resource if a default team has not been set in the provider.
        :param pulumi.Input[_builtins.str] vpc_id: The ID of the AWS VPC which hosts the network.
        """
        if aws_account_id is not None:
            pulumi.set(__self__, "aws_account_id", aws_account_id)
        if aws_availability_zone_ids is not None:
            pulumi.set(__self__, "aws_availability_zone_ids", aws_availability_zone_ids)
        if aws_region is not None:
            pulumi.set(__self__, "aws_region", aws_region)
        if cidr is not None:
            pulumi.set(__self__, "cidr", cidr)
        if egress_ip_addresses is not None:
            pulumi.set(__self__, "egress_ip_addresses", egress_ip_addresses)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if timeouts is not None:
            pulumi.set(__self__, "timeouts", timeouts)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @_builtins.property
    @pulumi.getter(name="awsAccountId")
    def aws_account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the AWS Account in which the network exists.
        """
        return pulumi.get(self, "aws_account_id")

    @aws_account_id.setter
    def aws_account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "aws_account_id", value)

    @_builtins.property
    @pulumi.getter(name="awsAvailabilityZoneIds")
    def aws_availability_zone_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The IDs of the AWS Availability Zones in which the network exists, if specified during creation.
        """
        return pulumi.get(self, "aws_availability_zone_ids")

    @aws_availability_zone_ids.setter
    def aws_availability_zone_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "aws_availability_zone_ids", value)

    @_builtins.property
    @pulumi.getter(name="awsRegion")
    def aws_region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The AWS Region in which the network exists.
        """
        return pulumi.get(self, "aws_region")

    @aws_region.setter
    def aws_region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "aws_region", value)

    @_builtins.property
    @pulumi.getter
    def cidr(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The CIDR range of the Network.
        """
        return pulumi.get(self, "cidr")

    @cidr.setter
    def cidr(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cidr", value)

    @_builtins.property
    @pulumi.getter(name="egressIpAddresses")
    def egress_ip_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The egress IP addresses of the Network.
        """
        return pulumi.get(self, "egress_ip_addresses")

    @egress_ip_addresses.setter
    def egress_ip_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "egress_ip_addresses", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the network.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Vercel region in which the Network exists.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the Network.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier of the Team that owns the Network. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)

    @_builtins.property
    @pulumi.getter
    def timeouts(self) -> Optional[pulumi.Input['NetworkTimeoutsArgs']]:
        return pulumi.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: Optional[pulumi.Input['NetworkTimeoutsArgs']]):
        pulumi.set(self, "timeouts", value)

    @_builtins.property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the AWS VPC which hosts the network.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "vpc_id", value)


@pulumi.type_token("vercel:index/network:Network")
class Network(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aws_availability_zone_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 cidr: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input[Union['NetworkTimeoutsArgs', 'NetworkTimeoutsArgsDict']]] = None,
                 __props__=None):
        """
        Provides a Network resource.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] aws_availability_zone_ids: The IDs of the AWS Availability Zones in which the network exists, if specified during creation.
        :param pulumi.Input[_builtins.str] cidr: The CIDR range of the Network.
        :param pulumi.Input[_builtins.str] name: The name of the network.
        :param pulumi.Input[_builtins.str] region: The Vercel region in which the Network exists.
        :param pulumi.Input[_builtins.str] team_id: The unique identifier of the Team that owns the Network. Required when configuring a team resource if a default team has not been set in the provider.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NetworkArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Network resource.

        :param str resource_name: The name of the resource.
        :param NetworkArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NetworkArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aws_availability_zone_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 cidr: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input[Union['NetworkTimeoutsArgs', 'NetworkTimeoutsArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NetworkArgs.__new__(NetworkArgs)

            __props__.__dict__["aws_availability_zone_ids"] = aws_availability_zone_ids
            if cidr is None and not opts.urn:
                raise TypeError("Missing required property 'cidr'")
            __props__.__dict__["cidr"] = cidr
            __props__.__dict__["name"] = name
            if region is None and not opts.urn:
                raise TypeError("Missing required property 'region'")
            __props__.__dict__["region"] = region
            __props__.__dict__["team_id"] = team_id
            __props__.__dict__["timeouts"] = timeouts
            __props__.__dict__["aws_account_id"] = None
            __props__.__dict__["aws_region"] = None
            __props__.__dict__["egress_ip_addresses"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["vpc_id"] = None
        super(Network, __self__).__init__(
            'vercel:index/network:Network',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            aws_account_id: Optional[pulumi.Input[_builtins.str]] = None,
            aws_availability_zone_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            aws_region: Optional[pulumi.Input[_builtins.str]] = None,
            cidr: Optional[pulumi.Input[_builtins.str]] = None,
            egress_ip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            team_id: Optional[pulumi.Input[_builtins.str]] = None,
            timeouts: Optional[pulumi.Input[Union['NetworkTimeoutsArgs', 'NetworkTimeoutsArgsDict']]] = None,
            vpc_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'Network':
        """
        Get an existing Network resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] aws_account_id: The ID of the AWS Account in which the network exists.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] aws_availability_zone_ids: The IDs of the AWS Availability Zones in which the network exists, if specified during creation.
        :param pulumi.Input[_builtins.str] aws_region: The AWS Region in which the network exists.
        :param pulumi.Input[_builtins.str] cidr: The CIDR range of the Network.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] egress_ip_addresses: The egress IP addresses of the Network.
        :param pulumi.Input[_builtins.str] name: The name of the network.
        :param pulumi.Input[_builtins.str] region: The Vercel region in which the Network exists.
        :param pulumi.Input[_builtins.str] status: The status of the Network.
        :param pulumi.Input[_builtins.str] team_id: The unique identifier of the Team that owns the Network. Required when configuring a team resource if a default team has not been set in the provider.
        :param pulumi.Input[_builtins.str] vpc_id: The ID of the AWS VPC which hosts the network.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NetworkState.__new__(_NetworkState)

        __props__.__dict__["aws_account_id"] = aws_account_id
        __props__.__dict__["aws_availability_zone_ids"] = aws_availability_zone_ids
        __props__.__dict__["aws_region"] = aws_region
        __props__.__dict__["cidr"] = cidr
        __props__.__dict__["egress_ip_addresses"] = egress_ip_addresses
        __props__.__dict__["name"] = name
        __props__.__dict__["region"] = region
        __props__.__dict__["status"] = status
        __props__.__dict__["team_id"] = team_id
        __props__.__dict__["timeouts"] = timeouts
        __props__.__dict__["vpc_id"] = vpc_id
        return Network(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="awsAccountId")
    def aws_account_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the AWS Account in which the network exists.
        """
        return pulumi.get(self, "aws_account_id")

    @_builtins.property
    @pulumi.getter(name="awsAvailabilityZoneIds")
    def aws_availability_zone_ids(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The IDs of the AWS Availability Zones in which the network exists, if specified during creation.
        """
        return pulumi.get(self, "aws_availability_zone_ids")

    @_builtins.property
    @pulumi.getter(name="awsRegion")
    def aws_region(self) -> pulumi.Output[_builtins.str]:
        """
        The AWS Region in which the network exists.
        """
        return pulumi.get(self, "aws_region")

    @_builtins.property
    @pulumi.getter
    def cidr(self) -> pulumi.Output[_builtins.str]:
        """
        The CIDR range of the Network.
        """
        return pulumi.get(self, "cidr")

    @_builtins.property
    @pulumi.getter(name="egressIpAddresses")
    def egress_ip_addresses(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The egress IP addresses of the Network.
        """
        return pulumi.get(self, "egress_ip_addresses")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the network.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The Vercel region in which the Network exists.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the Network.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> pulumi.Output[_builtins.str]:
        """
        The unique identifier of the Team that owns the Network. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @_builtins.property
    @pulumi.getter
    def timeouts(self) -> pulumi.Output[Optional['outputs.NetworkTimeouts']]:
        return pulumi.get(self, "timeouts")

    @_builtins.property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the AWS VPC which hosts the network.
        """
        return pulumi.get(self, "vpc_id")

